<?php

namespace Realestate\Plan\Http\Controllers;

use App\Http\Controllers\APIController as BaseController;
use Realestate\Plan\Http\Requests\SubscriptionUsageRequest;
use Realestate\Plan\Interfaces\SubscriptionUsageRepositoryInterface;
use Realestate\Plan\Models\SubscriptionUsage;
use Realestate\Plan\Forms\SubscriptionUsage as Form;

/**
 * APIController  class for subscription_usage.
 */
class SubscriptionUsageAPIController extends BaseController
{

    /**
     * Initialize subscription_usage resource controller.
     *
     * @param type SubscriptionUsageRepositoryInterface $subscription_usage
     *
     * @return null
     */
    public function __construct(SubscriptionUsageRepositoryInterface $subscription_usage)
    {
        parent::__construct();
        $this->repository = $subscription_usage;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Realestate\Plan\Repositories\Criteria\SubscriptionUsageResourceCriteria::class);
    }

    /**
     * Display a list of subscription_usage.
     *
     * @return Response
     */
    public function index(SubscriptionUsageRequest $request)
    {
        return $this->repository
            ->setPresenter(\Realestate\Plan\Repositories\Presenter\SubscriptionUsagePresenter::class)
            ->paginate();
    }

    /**
     * Display subscription_usage.
     *
     * @param Request $request
     * @param Model   $subscription_usage
     *
     * @return Response
     */
    public function show(SubscriptionUsageRequest $request, SubscriptionUsage $subscription_usage)
    {
        return $subscription_usage->setPresenter(\Realestate\Plan\Repositories\Presenter\SubscriptionUsageListPresenter::class);
        ;
    }

    /**
     * Create new subscription_usage.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(SubscriptionUsageRequest $request)
    {
        try {
            $data              = $request->all();
            $data['user_id']   = user_id();
            $data['user_type'] = user_type();
            $data              = $this->repository->create($data);
            $message           = trans('messages.success.created', ['Module' => trans('plan::subscription_usage.name')]);
            $code              = 204;
            $status            = 'success';
            $url               = guard_url('plan/subscription_usage/' . $subscription_usage->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('plan/subscription_usage');
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Update the subscription_usage.
     *
     * @param Request $request
     * @param Model   $subscription_usage
     *
     * @return Response
     */
    public function update(SubscriptionUsageRequest $request, SubscriptionUsage $subscription_usage)
    {
        try {
            $data = $request->all();

            $subscription_usage->update($data);
            $message = trans('messages.success.updated', ['Module' => trans('plan::subscription_usage.name')]);
            $code    = 204;
            $status  = 'success';
            $url     = guard_url('plan/subscription_usage/' . $subscription_usage->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('plan/subscription_usage/' . $subscription_usage->getRouteKey());
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Remove the subscription_usage.
     *
     * @param Model   $subscription_usage
     *
     * @return Response
     */
    public function destroy(SubscriptionUsageRequest $request, SubscriptionUsage $subscription_usage)
    {
        try {
            $subscription_usage->delete();
            $message = trans('messages.success.deleted', ['Module' => trans('plan::subscription_usage.name')]);
            $code    = 202;
            $status  = 'success';
            $url     = guard_url('plan/subscription_usage/0');
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('plan/subscription_usage/' . $subscription_usage->getRouteKey());
        }
        return compact('message', 'code', 'status', 'url');
    }

    /**
     * Return the form elements as json.
     *
     * @param String   $element
     *
     * @return json
     */
    public function form($element = 'fields')
    {
        $form = new Form();
        return $form->form($element, true);
    }

}
