<?php

namespace Realestate\Plan\Policies;

use Litepie\User\Contracts\UserPolicy;
use Realestate\Plan\Models\Feature;

class FeaturePolicy
{

    /**
     * Determine if the given user can view the feature.
     *
     * @param UserPolicy $user
     * @param Feature $feature
     *
     * @return bool
     */
    public function view(UserPolicy $user, Feature $feature)
    {
        if ($user->canDo('plan.feature.view') && $user->isAdmin()) {
            return true;
        }

        return $feature->user_id == user_id() && $feature->user_type == user_type();
    }

    /**
     * Determine if the given user can create a feature.
     *
     * @param UserPolicy $user
     * @param Feature $feature
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('plan.feature.create');
    }

    /**
     * Determine if the given user can update the given feature.
     *
     * @param UserPolicy $user
     * @param Feature $feature
     *
     * @return bool
     */
    public function update(UserPolicy $user, Feature $feature)
    {
        if ($user->canDo('plan.feature.edit') && $user->isAdmin()) {
            return true;
        }

        return $feature->user_id == user_id() && $feature->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given feature.
     *
     * @param UserPolicy $user
     * @param Feature $feature
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Feature $feature)
    {
        return $feature->user_id == user_id() && $feature->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given feature.
     *
     * @param UserPolicy $user
     * @param Feature $feature
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Feature $feature)
    {
        if ($user->canDo('plan.feature.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given feature.
     *
     * @param UserPolicy $user
     * @param Feature $feature
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Feature $feature)
    {
        if ($user->canDo('plan.feature.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
