<?php

namespace Realestate\Plan\Providers;

use Illuminate\Foundation\Support\Providers\RouteServiceProvider as ServiceProvider;
use Illuminate\Routing\Router;
use Realestate\Plan\Models\Plan;
use Request;
use Route;

class RouteServiceProvider extends ServiceProvider
{
    /**
     * This namespace is applied to the controller routes in your routes file.
     *
     * In addition, it is set as the URL generator's root namespace.
     *
     * @var string
     */
    protected $namespace = 'Realestate\Plan\Http\Controllers';

    /**
     * Define your route model bindings, pattern filters, etc.
     *
     * @param   \Illuminate\Routing\Router  $router
     * @return void
     */
    public function boot()
    {
        parent::boot();

        if (Request::is('*/plan/subscription_usage/*')) {
            Route::bind('subscription_usage', function ($subscription_usage) {
                $subscription_usagerepo = $this->app->make('Realestate\Plan\Interfaces\SubscriptionUsageRepositoryInterface');
                return $subscription_usagerepo->findorNew($subscription_usage);
            });
        }

        if (Request::is('*/plan/subscription/*')) {
            Route::bind('subscription', function ($subscription) {
                $subscriptionrepo = $this->app->make('Realestate\Plan\Interfaces\SubscriptionRepositoryInterface');
                return $subscriptionrepo->findorNew($subscription);
            });
        }

        if (Request::is('*/plan/feature/*')) {
            Route::bind('feature', function ($feature) {
                $featurerepo = $this->app->make('Realestate\Plan\Interfaces\FeatureRepositoryInterface');
                return $featurerepo->findorNew($feature);
            });
        }

        if (Request::is('*/plan/plan/*')) {
            Route::bind('plan', function ($plan) {
                $planrepo = $this->app->make('Realestate\Plan\Interfaces\PlanRepositoryInterface');
                return $planrepo->findorNew($plan);
            });
        }

    }

    /**
     * Define the routes for the package.
     *
     * @return void
     */
    public function map()
    {
        $this->mapWebRoutes();
    }

    /**
     * Define the "web" routes for the package.
     *
     * These routes all receive session state, CSRF protection, etc.
     *
     * @return void
     */
    protected function mapWebRoutes()
    {   
        Route::group([
            'middleware' => 'web',
            'namespace'  => $this->namespace,
        ], function ($router) {
            require (__DIR__ . '/../../routes/web.php');
        });
    }

}
